==> deepin-appstore_5.3.0.1.orig.tar.xz: deepin-appstore-5.3.0.1/translations/deepin-appstore_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="115"/>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="164"/>
        <source>Search &quot;%1&quot; in Deepin Store</source>
        <translation>Recherche &quot;%1&quot; dans le Deepin Store</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar.cpp" line="206"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="55"/>
        <source>Recommend App</source>
        <translation>Applications recommandées</translation>
    </message>
    <message>
        <source>Select region</source>
        <translation type="vanished"> Sélectionner la région</translation>
    </message>
    <message>
        <source>China</source>
        <translation type="vanished">Chine</translation>
    </message>
    <message>
        <source>International</source>
        <translation type="vanished">International</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="60"/>
        <source>Clear cache</source>
        <translation> Vider le cache</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="64"/>
        <source>Dark theme</source>
        <translation> Thème Sombre</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="70"/>
        <source>Privacy Policy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="73"/>
        <source>Undo</source>
        <translation>Défaire</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="78"/>
        <source>Redo</source>
        <translation>Refaire</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="84"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="89"/>
        <location filename="../src/ui/web_event_delegate.cpp" line="113"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="94"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="99"/>
        <source>Delete</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="105"/>
        <source>Select all</source>
        <translation>Tout sélectionner </translation>
    </message>
    <message>
        <location filename="../src/app/deepin_appstore.cpp" line="107"/>
        <source>Deepin Store</source>
        <translation>Deepin Store</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_appstore.cpp" line="108"/>
        <source>Deepin Store is an App Store with diverse and quality applications. It features popular recommendations, newly updated apps and hot topics, and supports one-click installation, updating and uninstalling.</source>
        <translation>Deepin Store est un magasin proposant de nombreuses applications de qualité. Il propose des recommandations populaires, des applications récemment mises à jour et des sujets d&apos;actualité et prend en charge l&apos;installation, la mise à jour et la désinstallation en un clic.</translation>
    </message>
</context>
<context>
    <name>dstore::UserMenu</name>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="13"/>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="16"/>
        <source>My comments</source>
        <translation>Mes commentaires</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="20"/>
        <source>My donations</source>
        <translation>Mes donations</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="24"/>
        <source>My apps</source>
        <translation>Mes applications</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="30"/>
        <source>Sign out</source>
        <translation>Déconnexion</translation>
    </message>
</context>
</TS>

==> deepin-appstore_5.3.1.5.orig.tar.xz: deepin-appstore-5.3.1.5/translations/deepin-appstore_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="115"/>
        <location filename="../src/ui/widgets/search_completion_window.cpp" line="164"/>
        <source>Search &quot;%1&quot; in Deepin Store</source>
        <translation>Recherche &quot;%1&quot; dans le Deepin Store</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar.cpp" line="206"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="55"/>
        <source>Recommend App</source>
        <translation>Applications recommandées</translation>
    </message>
    <message>
        <source>Select region</source>
        <translation type="vanished">Sélectionner la région</translation>
    </message>
    <message>
        <source>China</source>
        <translation type="vanished">Chine</translation>
    </message>
    <message>
        <source>International</source>
        <translation type="vanished">International</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="60"/>
        <source>Clear cache</source>
        <translation> Vider le cache</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="64"/>
        <source>Dark theme</source>
        <translation> Thème sombre</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/title_bar_menu.cpp" line="70"/>
        <source>Privacy Policy</source>
        <translation>Politique de confidentialité</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="73"/>
        <source>Undo</source>
        <translation>Défaire</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="78"/>
        <source>Redo</source>
        <translation>Refaire</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="84"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="89"/>
        <location filename="../src/ui/web_event_delegate.cpp" line="113"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="94"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="99"/>
        <source>Delete</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <location filename="../src/ui/web_event_delegate.cpp" line="105"/>
        <source>Select all</source>
        <translation>Tout sélectionner </translation>
    </message>
    <message>
        <location filename="../src/app/deepin_appstore.cpp" line="107"/>
        <source>Deepin Store</source>
        <translation>Deepin Store</translation>
    </message>
    <message>
        <location filename="../src/app/deepin_appstore.cpp" line="108"/>
        <source>Deepin Store is an App Store with diverse and quality applications. It features popular recommendations, newly updated apps and hot topics, and supports one-click installation, updating and uninstalling.</source>
        <translation>Deepin Store est un magasin proposant de nombreuses applications de qualité. Il propose des recommandations populaires, des applications récemment mises à jour et des sujets d&apos;actualité et prend en charge l&apos;installation, la mise à jour et la désinstallation en un clic.</translation>
    </message>
</context>
<context>
    <name>dstore::UserMenu</name>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="13"/>
        <source>Username</source>
        <translation>Nom d&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="16"/>
        <source>My comments</source>
        <translation>Mes commentaires</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="20"/>
        <source>My donations</source>
        <translation>Mes donations</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="24"/>
        <source>My apps</source>
        <translation>Mes applications</translation>
    </message>
    <message>
        <location filename="../src/ui/widgets/user_menu.cpp" line="30"/>
        <source>Sign out</source>
        <translation>Déconnexion</translation>
    </message>
</context>
</TS>
